Future Config interpreter for Python
===================

Installation:

    pip install fconfig

Usage: see the `wiki <https://github.com/F-I-D-O/Future-Config/wiki>`



This package uses doctest for testing, run :code:`doctest left_pad.py` to run the tests.